<?php
/**
 * @project Astra.CMS
 * @link http://a-cms.ru/
 * @copyright 2011 "Астра Вебтехнологии"
 * @author Vitaly Hohlov <admin@a-cms.ru>
 * @package Modules
 */
/**************************************************************************/

/**
 * Генерация ссылки на страницу категории.
 *
 * @param integer $id Идентификатор категории.
 * @param string $section Полный строковой идентификатор раздела.
 * @return string
 */

function board_createCategoryLink($id,$section)
{ static $cache=array();
  if(isset($cache[$section][$id]))
  return $cache[$section][$id];
  if($row=A::$DB->getRow("SELECT idker,urlname FROM {$section}_categories WHERE id=".(integer)$id))
  return $cache[$section][$id]=board_createCategoryLink($row['idker'],$section).$row['urlname']."/";
  else
  return $cache[$section][$id]=getSectionLink($section);
}

/**
 * Генерация ссылки на детальную страницу вопроса.
 *
 * @param integer $id Идентификатор материала.
 * @param string $section Полный строковой идентификатор раздела.
 * @return string
 */

function board_createItemLink($id,$section)
{ static $cache=array();
  if(isset($cache[$section][$id]))
  return $cache[$section][$id];
  else
  return $cache[$section][$id]=getSectionLink($section).sprintf("%06d",$id).".html";
}

/**
 * Интеграция в карту сайта ссылок на категории.
 *
 * @param object &$treeitem Объект дерева карты сайта.
 * @param string $section Полный строковой идентификатор раздела.
 * @param integer $id=0 Идентификатор родительской категории.
 */

function board_createMap_Categories(&$treeitem,$section,$id=0)
{
  A::$DB->query("SELECT * FROM {$section}_categories WHERE idker={$id} AND active='Y' ORDER BY sort");
  while($row=A::$DB->fetchRow())
  { $treeitem->items[$row['id']] = new SiteMap_Box($row['name'],board_createCategoryLink($row['id'],$section));
    board_createMap_Categories($treeitem->items[$row['id']],$section,$row['id']);
  }
  A::$DB->free();
}

/**
 * Интеграция в карту сайта.
 *
 * @param object &$treemap Объект дерева карты сайта.
 * @param string $section Полный строковой идентификатор раздела.
 * @param string $caption Название раздела.
 */

function board_createMap(&$treemap,$section,$caption)
{
  $treemap->items[$section] = new SiteMap_Box($caption,getSectionLink($section));
  board_createMap_Categories($treemap->items[$section],$section);
}

/**
 * Интеграция вариантов доступа.
 *
 * @param array &$access Массив вариантов доступа.
 */

function board_Access(&$access)
{
  $access[]=array('name'=>'add','caption'=>"Добавление записей",'auth'=>true);
  $access[]=array('name'=>'edit','caption'=>"Редактирование своих записей",'auth'=>true);
  $access[]=array('name'=>'del','caption'=>"Удаление своих записей",'auth'=>true);
}

/**
 * Индексация всех материалов в базу поиска по сайту.
 *
 * @param string $section Полный строковой идентификатор раздела.
 */

function board_searchIndexAll($section)
{
  $idsec=getSectionId($section);
  A::$DB->query("SELECT id,description,tags FROM {$section}_categories WHERE active='Y'");
  while($row=A::$DB->fetchRow())
  A_SearchEngine::getInstance()->updateIndex($idsec,-$row['id'],getTreePath($section."_categories",$row['id']," - "),$row['description'],$row['tags']);
  A::$DB->free();
  A::$DB->query("SELECT id,name,content FROM {$section}_catalog WHERE active='Y'");
  while($row=A::$DB->fetchRow())
  A_SearchEngine::getInstance()->updateIndex($idsec,$row['id'],$row['name'],$row['content']);
  A::$DB->free();
}

/**
 * Получение полных данных записи.
 *
 * @param integer $id Идентификатор записи.
 * @param string $section Полный строковой идентификатор раздела.
 * @param integer $idsec=0 Числовой идентификатор раздела.
 * @return array
 */

function board_getItem($id,$section,$idsec=0)
{ static $cache=array();
  if(isset($cache[$section][$id]))
  return $cache[$section][$id];
  if($row=A::$DB->getRow("SELECT * FROM {$section}_catalog WHERE id=?i AND active='Y'",$id))
  { if(!$idsec)
    $idsec=getSectionId($section);
    $row['link']=board_createItemLink($row['id'],$section);
    $row['categories']=array();
	if($idcats=A::$DB->getCol("SELECT DISTINCT idcat FROM {$section} WHERE iditem={$row['id']} ORDER BY id"))
    foreach($idcats as $idcat)
	$row['categories'][]=array('name'=>getTreePath("{$section}_categories",$idcat),'link'=>board_createCategoryLink($idcat,$section));
	$row['images']=A::$DB->getAll("SELECT * FROM ".DOMAIN."_images WHERE idsec=? AND iditem=? ORDER BY sort",array($idsec,$row['id']));
	$row['idimg']=isset($row['images'][0]['id'])?$row['images'][0]['id']:0;
	prepareValues($section,$row);
	$row=A::$OBSERVER->Modifier('board_prepareValues',$section,$row);
    return $cache[$section][$id]=$row;
  }
  else
  return $cache[$section][$id]=false;
}